pub enum LabelPosition {
Left,
Right,
}Expand description
Position of the label relative to the toggle switch
Variants
Left
Label appears to the left of the toggle
Right
Label appears to the right of the toggle (default)