pub struct StringItem { /* private fields */ }Expand description
A simple string-based selection item
Use this type for simple string selections without defining a custom enum. The label and id are both derived from the string value.
Example
ⓘ
use ccf_gpui_widgets::widgets::{RadioGroup, StringItem};
let radio = cx.new(|cx| {
RadioGroup::new(
vec![
StringItem::new("small"),
StringItem::new("medium"),
StringItem::new("large"),
],
StringItem::new("medium"),
cx,
)
});Implementations