GPUI widgets
Structs
- Checkbox
- Checkbox widget
- Checkbox
Group - Checkbox group widget for multi-selection
- Collapsible
- Collapsible section widget
- Color
Swatch - Color swatch widget with hex input and color picker
- Confirmation
Dialog - Confirmation dialog widget
- Directory
Picker - Directory picker widget
- Dropdown
- Dropdown/Select widget
- File
Picker - File picker widget
- Focus
Next - Focus
Prev - Number
Stepper - Number stepper widget with +/- buttons
- Password
Input - Password input widget with visibility toggle
- Progress
Bar - Progress bar widget
- Radio
Group - Radio group widget for single-selection
- Repeatable
Activate Button - Repeatable
Directory Picker - Repeatable directory picker widget
- Repeatable
File Picker - Repeatable file picker widget
- Repeatable
Text Input - Repeatable text input widget
- Scrollable
- A scroll view with visible scrollbars
- Segment
Option - A single option in the segmented control
- Segmented
Control - Segmented control widget for single-selection from horizontal options
- Sidebar
Nav - Generic sidebar navigation widget
- Slider
- Slider widget for selecting numeric values
- Spinner
- Spinner widget
- String
Item - A simple string-based selection item
- TabBar
- Generic tab bar widget
- Text
Input - Text input widget state
- Toggle
Switch - Toggle switch widget
- Tooltip
- A simple tooltip view for displaying text messages
Enums
- Checkbox
Event - Events emitted by Checkbox
- Checkbox
Group Event - Events emitted by CheckboxGroup
- Collapsible
Event - Events emitted by Collapsible
- Color
Swatch Event - Events emitted by ColorSwatch
- Confirmation
Dialog Event - Events emitted by ConfirmationDialog
- Dialog
Button - Which button a key or action should trigger
- Dialog
Style - Dialog style/severity (controls primary button color)
- Directory
Picker Event - Events emitted by DirectoryPicker
- Directory
Picker Validation - Validation state for DirectoryPicker
- Directory
Validation Display - Controls how validation feedback is displayed in file/directory pickers
- Dropdown
Event - Events emitted by Dropdown
- File
Mode - File picker modes
- File
Picker Event - Events emitted by FilePicker
- File
Picker Validation - Validation state for FilePicker
- Label
Position - Position of the label relative to the toggle switch
- Missing
Directories - How to handle missing parent directories
- Number
Stepper Event - Events emitted by NumberStepper
- Password
Input Event - Events emitted by PasswordInput
- Picker
Mode - Color picker mode (RGB or HSL sliders)
- Progress
BarEvent - Events emitted by ProgressBar
- Radio
Group Event - Events emitted by RadioGroup
- Repeatable
Directory Picker Event - Events emitted by RepeatableDirectoryPicker
- Repeatable
File Picker Event - Events emitted by RepeatableFilePicker
- Repeatable
Text Input Event - Events emitted by RepeatableTextInput
- Scrollbar
Axis - Axis options for scrollbar display
- Segmented
Control Event - Events emitted by SegmentedControl
- Sidebar
NavEvent - Events emitted by SidebarNav
- Slider
Event - Events emitted by Slider
- Spinner
Size - Spinner size presets
- TabBar
Event - Events emitted by TabBar
- Text
Input Event - Events emitted by TextInput
- Toggle
Switch Event - Events emitted by ToggleSwitch
- Validation
Display - Controls how validation feedback is displayed in file/directory pickers
Traits
- Enabled
Cursor Ext - Extension trait for applying cursor styling based on enabled state.
- Selection
Item - Trait for items that can be displayed in selection widgets
Functions
- danger_
button - Create a danger button with the specified label
- primary_
button - Create a primary button with the specified label
- register_
all_ keybindings - Register all widget keybindings
- register_
button_ keybindings - Register key bindings for button components
- register_
color_ swatch_ keybindings - Register key bindings for color swatch components
- register_
directory_ picker_ keybindings - Register key bindings for directory picker
- register_
dropdown_ keybindings - Register key bindings for dropdown components
- register_
file_ picker_ keybindings - Register key bindings for file picker
- register_
focus_ navigation_ keybindings - Register Tab and Shift+Tab key bindings for focus navigation.
- register_
repeatable_ text_ input_ keybindings - Register key bindings for repeatable text input buttons
- register_
sidebar_ nav_ keybindings - Register key bindings for sidebar nav components
- register_
tab_ bar_ keybindings - Register key bindings for tab bar components
- register_
text_ input_ keybindings - Register key bindings for text input components
- repeatable_
add_ button - Render a repeatable widget add button (plus icon).
- repeatable_
remove_ button - Render a repeatable widget remove button (minus icon).
- scrollable_
both - Create a scrollable container with both axes
- scrollable_
horizontal - Create a horizontal scrollable container
- scrollable_
vertical - Create a vertical scrollable container
- secondary_
button - Create a secondary button with the specified label
- validate_
directory_ path - Validate a directory path
- validate_
file_ path - Validate a file path for the given mode and missing directories policy
- with_
focus_ actions - Apply standard focus navigation actions (Tab / Shift+Tab) to an element.
Type Aliases
- Secret
String - Secret string type.