FilePicker

Struct FilePicker 

pub struct FilePicker { /* private fields */ }
File picker widget

Implementations

Source

impl FilePicker

pub fn new(cx: &mut Context<'_, Self>) -> Self

Create a new file picker

pub fn with_value(self, path: impl Into<String>) -> Self

Set initial value (builder pattern)

pub fn placeholder(self, text: impl Into<SharedString>) -> Self

Set placeholder text (builder pattern)

pub fn extensions(self, extensions: Vec<String>) -> Self

Set file extensions filter (builder pattern)

pub fn mode(self, mode: FileMode) -> Self

Set file mode (builder pattern)

pub fn missing_directories(self, handling: MissingDirectories) -> Self

Set missing directories handling (builder pattern)

pub fn theme(self, theme: Theme) -> Self

Set custom theme (builder pattern)

pub fn browse_shortcut(self, enabled: bool) -> Self

Enable or disable Cmd+O / Ctrl+O browse shortcut (builder pattern)

The shortcut is enabled by default. Disable it if your application uses Cmd+O for another purpose (e.g., opening files at the app level).

pub fn validation_display(self, display: ValidationDisplay) -> Self

Set how validation feedback is displayed (builder pattern)

Controls whether path coloring and/or explanation messages are shown. Default is ValidationDisplay::Full (show both).

pub fn with_enabled(self, enabled: bool) -> Self

Set whether the widget is enabled (builder pattern)

When disabled, the widget cannot be edited or browsed. Default is true.

pub fn is_enabled(&self) -> bool

Returns whether the widget is enabled

pub fn set_enabled(&mut self, enabled: bool, cx: &mut Context<'_, Self>)

Set whether the widget is enabled

pub fn value(&self) -> &str

Get the current file path

pub fn set_value(&mut self, path: &str, cx: &mut Context<'_, Self>)

Set value programmatically

pub fn focus_handle(&self) -> &FocusHandle

Get the focus handle

pub fn focus(&mut self, cx: &mut Context<'_, Self>)

Focus the edit button (the primary interactive element)

Note: This is deferred to the next render to avoid triggering a synthetic click from keyup events.

pub fn needs_directory_creation(&self) -> bool

Returns true if this file picker needs directory creation

pub fn directory_to_create(&self) -> Option<PathBuf>

Returns the parent directory path if it needs to be created

pub fn validate(&self) -> FilePickerValidation

Validate the current path and return the validation state

Use this to check if the path is valid before taking action.

pub fn is_valid(&self) -> bool

Returns true if the current path is valid for the configured mode

For Open mode: path must exist and be a file. For Save mode: path must not be a directory, and either:

  • Parent exists (file will be created or overwritten), or
  • MissingDirectories is Create/Okay (path will be created)